@@ -58,12 +58,14 @@ mosaic <- function(bases, bases2=NULL, blend=FALSE, ...) {
   if(blend) {
     # calculate affinities using relative abundances of basis species
     e <- equilibrate(A.bases)
+    # what is the total activity of the basis species?
+    a.tot <- Reduce("+", lapply(e$loga.equil, function(x) 10^x))
     for(j in seq_along(affs)) {
       for(i in seq_along(A.species$values)) {
         # start with zero affinity
         if(j==1) A.species$values[[i]][] <- 0
-        # add affinity scaled by relative abundance of this basis species
-        A.species$values[[i]] <- A.species$values[[i]] + affs[[j]]$values[[i]] * 10^e$loga.equil[[j]]
+        # add affinity scaled by __relative__ abundance of this basis species
+        A.species$values[[i]] <- A.species$values[[i]] + affs[[j]]$values[[i]] * 10^e$loga.equil[[j]]/a.tot
       }
     }
   } else {
