@@ -17,17 +17,20 @@ caller.name <- function(n=2) {
   return(name)
 }
 
-palply <- function(X, FUN, ...) {
-  # a wrapper function to run parLapply if length(X) > 10000
+palply <- function(varlist, X, FUN, ...) {
+  # a wrapper function to run parLapply if length(X) >= thermo$opt$paramin
   # and package 'parallel' is available, otherwise run lapply
-  if(length(X) > 10000 & "parallel" %in% (.packages())) {
-    # the calculations - modified from ?parLapply
-    ## Use option mc.cores to choose an appropriate cluster size.
-    # or detectCores if that is NULL, and set max at 2 for now
-    # (to be nice to CRAN etc.)
-    nCores <- max(getOption("mc.cores", parallel::detectCores()), 2)
+  if(length(X) >= get("thermo")$opt$paramin) {
+    # Use option mc.cores to choose an appropriate cluster size.
+    # and set max at 2 for now (per CRAN policies)
+    nCores <- min(getOption("mc.cores"), 2)
     # don't load methods package, to save startup time - ?makeCluster
     cl <- parallel::makeCluster(nCores, methods=FALSE)
+    # export the variables and notify the user
+    if(! "" %in% varlist) parallel::clusterExport(cl, varlist)
+    msgout(paste("palply:", caller.name(4), "running", length(X), "calculations on",
+      nCores, "cores with variable(s)", paste(varlist, collapse=", "), "\n"))
+    # run the calculations
     out <- parallel::parLapply(cl, X, FUN, ...)
     parallel::stopCluster(cl)
   } else out <- lapply(X, FUN, ...)
