@@ -264,13 +264,12 @@ guess <- function(
     if(!"limSolve" %in% row.names(installed.packages())) {
       msgout("guess: skipping 'central' method as limSolve package is not available\n")
     } else {
-      require(limSolve)
       # the inequality constraints for moles of species
       G <- diag(nrow(A))
       # minX is the minimum mole number we will accept
       H <- rep(minX, nrow(A))
       # get a solution
-      X <- xranges(E=t(A), F=B, G=G, H=H, central=TRUE, full=TRUE)[, "central"]
+      X <- limSolve::xranges(E=t(A), F=B, G=G, H=H, central=TRUE, full=TRUE)[, "central"]
       return(X)
     }
   }
